aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorolim <bobq4582@gmail.com>2024-06-26 12:05:44 +0100
committerolim <bobq4582@gmail.com>2024-07-15 12:38:00 +0100
commit8c14a57681e0fabb113b51e4c066c2b4ddf8ab03 (patch)
treea0f5fa23cfc3cef91aa534d77b8d1e1b7354b1fa /src
parent50827a487b06cab710ed6c29e48c3b8fe88ad881 (diff)
downloadSkyblocker-8c14a57681e0fabb113b51e4c066c2b4ddf8ab03.tar.gz
Skyblocker-8c14a57681e0fabb113b51e4c066c2b4ddf8ab03.tar.bz2
Skyblocker-8c14a57681e0fabb113b51e4c066c2b4ddf8ab03.zip
fix issues
fix issues. and remove unnecessary square root
Diffstat (limited to 'src')
-rw-r--r--src/main/java/de/hysky/skyblocker/mixins/PlayerListHudMixin.java2
-rw-r--r--src/main/java/de/hysky/skyblocker/skyblock/dwarven/WishingCompassSolver.java8
2 files changed, 4 insertions, 6 deletions
diff --git a/src/main/java/de/hysky/skyblocker/mixins/PlayerListHudMixin.java b/src/main/java/de/hysky/skyblocker/mixins/PlayerListHudMixin.java
index 038d4e4f..2c7fde47 100644
--- a/src/main/java/de/hysky/skyblocker/mixins/PlayerListHudMixin.java
+++ b/src/main/java/de/hysky/skyblocker/mixins/PlayerListHudMixin.java
@@ -43,8 +43,6 @@ public class PlayerListHudMixin {
w = (int) (w / scale);
h = (int) (h / scale);
- PlayerListMgr.updateFooter(footer);
-
try {
ScreenMaster.render(context, w,h);
// Screen screen = Screen.getCorrect(w, h, footer);
diff --git a/src/main/java/de/hysky/skyblocker/skyblock/dwarven/WishingCompassSolver.java b/src/main/java/de/hysky/skyblocker/skyblock/dwarven/WishingCompassSolver.java
index 566af8e7..f028e3e7 100644
--- a/src/main/java/de/hysky/skyblocker/skyblock/dwarven/WishingCompassSolver.java
+++ b/src/main/java/de/hysky/skyblocker/skyblock/dwarven/WishingCompassSolver.java
@@ -69,9 +69,9 @@ public class WishingCompassSolver {
*/
private static final double PARTICLES_MAX_DISTANCE = 0.9;
/**
* the distance the player has to be from where they used the first compass to where they use the second
*/
- private static final long DISTANCE_BETWEEN_USES = 8;
+ private static final long DISTANCE_BETWEEN_USES = 64;
private static SolverStates currentState = SolverStates.NOT_STARTED;
private static Vec3d startPosOne = Vec3d.ZERO;
@@ -340,7 +340,7 @@ public class WishingCompassSolver {
case WAITING_FOR_SECOND -> {
//only continue if the player is far enough away from the first position to get a better reading
- if (startPosOne.distanceTo(playerPos) < DISTANCE_BETWEEN_USES) {
+ if (startPosOne.squaredDistanceTo(playerPos) < DISTANCE_BETWEEN_USES) {
CLIENT.player.sendMessage(Constants.PREFIX.get().append(Text.translatable("skyblocker.config.mining.crystalsWaypoints.wishingCompassSolver.moveFurtherMessage")), false);
return true;
} else {
@@ -357,7 +357,7 @@ public class WishingCompassSolver {
case PROCESSING_FIRST_USE, PROCESSING_SECOND_USE -> {
//if still looking for particles for line tell the user to wait
- //else tell the use something went wrong and its starting again
+ //else tell the user something went wrong and its starting again
if (System.currentTimeMillis() - particleLastUpdate < PARTICLES_MAX_DELAY) {
CLIENT.player.sendMessage(Constants.PREFIX.get().append(Text.translatable("skyblocker.config.mining.crystalsWaypoints.wishingCompassSolver.waitLongerMessage").formatted(Formatting.RED)), false);
return true;
@@ -69,9 +69,9 @@ public class WishingCompassSolver {
private static final double PARTICLES_MAX_DISTANCE = 0.9;
/**
- * the distance the player has to be from where they used the first compass to where they use the second
+ * the distance squared the player has to be from where they used the first compass to where they use the second
*/